@@ -1,5 +1,5 @@
-// +build go1.6
-// +build !go1.7
+// +build go1.7
+// +build !go1.8
 
 package gorequest
 
@@ -21,10 +21,14 @@ func (s *SuperAgent) safeModifyTransport() {
         TLSHandshakeTimeout:    oldTransport.TLSHandshakeTimeout,
         DisableKeepAlives:      oldTransport.DisableKeepAlives,
         DisableCompression:     oldTransport.DisableCompression,
+        MaxIdleConns:           oldTransport.MaxIdleConns,
         MaxIdleConnsPerHost:    oldTransport.MaxIdleConnsPerHost,
         ResponseHeaderTimeout:  oldTransport.ResponseHeaderTimeout,
-        // new in 1.6
         ExpectContinueTimeout:  oldTransport.ExpectContinueTimeout,
         TLSNextProto:           oldTransport.TLSNextProto,
+        // new in go1.7
+        DialContext:            oldTransport.DialContext,
+        IdleConnTimeout:        oldTransport.IdleConnTimeout,
+        MaxResponseHeaderBytes: oldTransport.MaxResponseHeaderBytes,
     }
 }
